// src/global_preferences.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef GLOBAL_PREFERENCES_HH
#define GLOBAL_PREFERENCES_HH 1

#include "config.h"

#include <glibmm/ustring.h>
#include <vector>

// Do not include complete template definition here:
#include "singleton.hh"

namespace sgpem
{
  class GlobalPreferences;
}

#include "config.h"

namespace sgpem
{
  class SG_DLLEXPORT GlobalPreferences : public Singleton<GlobalPreferences>
  {
    friend class Singleton<GlobalPreferences>;

  public:
    typedef std::vector<Glib::ustring>::const_iterator dir_iterator;

    dir_iterator modules_dir_begin() const;
    dir_iterator modules_dir_end() const;

    dir_iterator policies_dir_begin() const;
    dir_iterator policies_dir_end() const;

    void add_modules_dir(const Glib::ustring& moddir);
    void add_policies_dir(const Glib::ustring& poldir);

  private:
    GlobalPreferences();
    GlobalPreferences(const GlobalPreferences&);
    GlobalPreferences& operator=(const GlobalPreferences&);

    std::vector<Glib::ustring>  _mod_dirs;
    std::vector<Glib::ustring>  _pol_dirs;
  };
}

#endif
