// src/backend/plugin.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef SGPEMV2__PLUGIN_HH
#define SGPEMV2__PLUGIN_HH 1

#include "config.h"

#include <glibmm/ustring.h>

/** \file plugin.hh
 * All loadable modules that want to act as plugins
 * for SGPEMv2 should implement this interface. */

namespace sgpem
{
  /** \brief The interface a specific plugin should implement
   *
          * Only the header file containing this interface 
   * should be provided by the backend library. Every plugin 
   * will then implement its set of static functions. 
   * Thus every plugin will export these very symbols 
   * outside its DSO.
   */
  class SG_DLLEXPORT Plugin
  {
    /** \brief Called when a plugin is loaded and enabled
     *
     * Sets up the plugin's initial state and 
     * performs needed actions before its usage can start.
     */
    static void          SG_DLLEXPORT on_init();

    static void          SG_DLLEXPORT on_exit();
    static Glib::ustring SG_DLLEXPORT describe();
    static Glib::ustring SG_DLLEXPORT get_name();
    static Glib::ustring SG_DLLEXPORT get_author();
    static float         SG_DLLEXPORT get_version();

  private:
    SG_DLLLOCAL Plugin();
  }
  ; //~ class Plugin

} //~ namespace sgpem

#endif
